==> zio-aws-kinesisanalyticsv2_2.13-6.20.83.1-sources.jar: zio/aws/kinesisanalyticsv2/model/DeleteApplicationInputProcessingConfigurationRequest.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.{
  Id,
  ApplicationVersionId,
  ApplicationName
}
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteApplicationInputProcessingConfigurationRequest(
    applicationName: ApplicationName,
    currentApplicationVersionId: ApplicationVersionId,
    inputId: Id
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest = {
    import DeleteApplicationInputProcessingConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest
      .builder()
      .applicationName(
        ApplicationName.unwrap(applicationName): java.lang.String
      )
      .currentApplicationVersionId(
        ApplicationVersionId.unwrap(currentApplicationVersionId): java.lang.Long
      )
      .inputId(Id.unwrap(inputId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest
      .wrap(buildAwsValue())
}
object DeleteApplicationInputProcessingConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest =
      zio.aws.kinesisanalyticsv2.model
        .DeleteApplicationInputProcessingConfigurationRequest(
          applicationName,
          currentApplicationVersionId,
          inputId
        )
    def applicationName: ApplicationName
    def currentApplicationVersionId: ApplicationVersionId
    def inputId: Id
    def getApplicationName: ZIO[Any, Nothing, ApplicationName] =
      ZIO.succeed(applicationName)
    def getCurrentApplicationVersionId
        : ZIO[Any, Nothing, ApplicationVersionId] =
      ZIO.succeed(currentApplicationVersionId)
    def getInputId: ZIO[Any, Nothing, Id] = ZIO.succeed(inputId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest
  ) extends zio.aws.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest.ReadOnly {
    override val applicationName: ApplicationName =
      zio.aws.kinesisanalyticsv2.model.primitives
        .ApplicationName(impl.applicationName())
    override val currentApplicationVersionId: ApplicationVersionId =
      zio.aws.kinesisanalyticsv2.model.primitives
        .ApplicationVersionId(impl.currentApplicationVersionId())
    override val inputId: Id =
      zio.aws.kinesisanalyticsv2.model.primitives.Id(impl.inputId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest
  ): zio.aws.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kinesisanalyticsv2_3-5.17.124.1-sources.jar: zio/aws/kinesisanalyticsv2/model/DeleteApplicationInputProcessingConfigurationRequest.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.{
  Id,
  ApplicationVersionId,
  ApplicationName
}
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteApplicationInputProcessingConfigurationRequest(
    applicationName: ApplicationName,
    currentApplicationVersionId: ApplicationVersionId,
    inputId: Id
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest = {
    import DeleteApplicationInputProcessingConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest
      .builder()
      .applicationName(
        ApplicationName.unwrap(applicationName): java.lang.String
      )
      .currentApplicationVersionId(
        ApplicationVersionId.unwrap(currentApplicationVersionId): java.lang.Long
      )
      .inputId(Id.unwrap(inputId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest
      .wrap(buildAwsValue())
}
object DeleteApplicationInputProcessingConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest =
      zio.aws.kinesisanalyticsv2.model
        .DeleteApplicationInputProcessingConfigurationRequest(
          applicationName,
          currentApplicationVersionId,
          inputId
        )
    def applicationName: ApplicationName
    def currentApplicationVersionId: ApplicationVersionId
    def inputId: Id
    def getApplicationName: ZIO[Any, Nothing, ApplicationName] =
      ZIO.succeed(applicationName)
    def getCurrentApplicationVersionId
        : ZIO[Any, Nothing, ApplicationVersionId] =
      ZIO.succeed(currentApplicationVersionId)
    def getInputId: ZIO[Any, Nothing, Id] = ZIO.succeed(inputId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest
  ) extends zio.aws.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest.ReadOnly {
    override val applicationName: ApplicationName =
      zio.aws.kinesisanalyticsv2.model.primitives
        .ApplicationName(impl.applicationName())
    override val currentApplicationVersionId: ApplicationVersionId =
      zio.aws.kinesisanalyticsv2.model.primitives
        .ApplicationVersionId(impl.currentApplicationVersionId())
    override val inputId: Id =
      zio.aws.kinesisanalyticsv2.model.primitives.Id(impl.inputId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest
  ): zio.aws.kinesisanalyticsv2.model.DeleteApplicationInputProcessingConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
